@@ -41,7 +41,10 @@ class ModelFactory:
     def image_input(self) -> tf.Tensor:
         if not hasattr(self, "_image_input"):
             input_shape = utils.validate_input(
-                self.input_shape, self.weights, self.include_top, self.num_classes,
+                self.input_shape,
+                self.weights,
+                self.include_top,
+                self.num_classes,
             )
             self._image_input = utils.get_input_layer(input_shape, self.input_tensor)
         return self._image_input
